@@ -17,12 +17,11 @@ from oslo_db.sqlalchemy import models
 from oslo_utils import timeutils
 from sqlalchemy import (Column, DateTime, Index, Integer, Enum, String,
                         schema)
-from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy import orm
 from sqlalchemy import ForeignKey, Boolean, Text
 
 
-BASE = declarative_base()
+BASE = orm.declarative_base()
 
 
 class MasakariTimestampMixin(object):
@@ -87,6 +86,7 @@ class FailoverSegment(BASE, MasakariAPIBase, models.SoftDeleteMixin):
     uuid = Column(String(36), nullable=False)
     name = Column(String(255), nullable=False)
     service_type = Column(String(255), nullable=False)
+    enabled = Column(Boolean, default=True)
     description = Column(Text)
     recovery_method = Column(Enum('auto', 'reserved_host', 'auto_priority',
                                   'rh_priority',
@@ -140,3 +140,27 @@ class Notification(BASE, MasakariAPIBase, models.SoftDeleteMixin):
                          'ignored', 'finished', name='notification_status'),
                     nullable=False)
     source_host_uuid = Column(String(36), nullable=False)
+    failover_segment_uuid = Column(String(36), nullable=False)
+    message = Column(Text)
+
+
+class VMove(BASE, MasakariAPIBase, models.SoftDeleteMixin):
+    """Represents one vm move."""
+    __tablename__ = 'vmoves'
+    __table_args__ = (
+        schema.UniqueConstraint('uuid',
+                                name='uniq_vmove0uuid'),
+    )
+
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    uuid = Column(String(36), nullable=False)
+    notification_uuid = Column(String(36), nullable=False)
+    instance_uuid = Column(String(36), nullable=False)
+    instance_name = Column(String(255), nullable=False)
+    source_host = Column(String(255), nullable=True)
+    dest_host = Column(String(255), nullable=True)
+    start_time = Column(DateTime, nullable=True)
+    end_time = Column(DateTime, nullable=True)
+    type = Column(String(36), nullable=True)
+    status = Column(String(255), nullable=True)
+    message = Column(Text)
