@@ -177,11 +177,16 @@ class MasakariManager(manager.Manager):
         notification_event = notification.payload.get('event')
         exception_info = None
 
-        if host_status.upper() != fields.HostStatusType.NORMAL:
+        if host_status is None:
+            LOG.warning("Notification '%(uuid)s' ignored as host_status is "
+                        "not provided.",
+                        {'uuid': notification.notification_uuid})
+            notification_status = fields.NotificationStatus.IGNORED
+        elif host_status.upper() != fields.HostStatusType.NORMAL:
             # NOTE(shilpasd): Avoid host recovery for host_status other than
             # 'NORMAL' otherwise it could lead to unsafe evacuation of
             # instances running on the failed source host.
-            LOG.warning("Notification '%(uuid)s' ignored as host_status"
+            LOG.warning("Notification '%(uuid)s' ignored as host_status "
                         "is '%(host_status)s'",
                         {'uuid': notification.notification_uuid,
                          'host_status': host_status.upper()})
@@ -207,6 +212,7 @@ class MasakariManager(manager.Manager):
             if host_obj.reserved:
                 update_data['reserved'] = False
 
+            LOG.info("Set host %s on maintenance.", host_name)
             host_obj.update(update_data)
             host_obj.save()
 
@@ -333,6 +339,7 @@ class MasakariManager(manager.Manager):
         if not host.failover_segment.enabled:
             update_data = {
                 'status': fields.NotificationStatus.IGNORED,
+                'message': 'Recovery aboart: the segment HA is disabled.',
             }
             notification.update(update_data)
             notification.save()
