@@ -16,7 +16,7 @@
 """Tests for the notifications api."""
 
 import copy
-from http import client as http
+from http import HTTPStatus
 from unittest import mock
 
 import ddt
@@ -31,8 +31,8 @@ from masakari.ha import api as ha_api
 from masakari.objects import base as obj_base
 from masakari.objects import fields
 from masakari.objects import notification as notification_obj
-from masakari import test
 from masakari.tests.unit.api.openstack import fakes
+from masakari.tests.unit import base
 from masakari.tests.unit.objects import test_objects
 from masakari.tests import uuidsentinel
 
@@ -61,6 +61,8 @@ NOTIFICATION_DATA = {"type": "VM", "id": 1,
                      "generated_time": NOW,
                      "status": "running",
                      "notification_uuid": uuidsentinel.fake_notification,
+                     "failover_segment_uuid": uuidsentinel.fake_segment,
+                     "message": None,
                      "created_at": NOW,
                      "updated_at": None,
                      "deleted_at": None,
@@ -89,14 +91,18 @@ NOTIFICATION_LIST = [
     {"type": "VM", "id": 1, "payload": {'event': 'STOPPED',
                                         'host_status': 'NORMAL',
                                         'cluster_status': 'ONLINE'},
-     "source_host_uuid": uuidsentinel.fake_host, "generated_time": NOW,
+     "source_host_uuid": uuidsentinel.fake_host,
+     "generated_time": NOW,
      "status": "running", "notification_uuid": uuidsentinel.fake_notification,
+     "failover_segment_uuid": uuidsentinel.fake_segment, "message": None,
      "created_at": NOW, "updated_at": None, "deleted_at": None, "deleted": 0},
 
     {"type": "PROCESS", "id": 2, "payload": {'event': 'STOPPED',
                                              'process_name': 'fake_process'},
-     "source_host_uuid": uuidsentinel.fake_host1, "generated_time": NOW,
+     "source_host_uuid": uuidsentinel.fake_host_1,
+     "generated_time": NOW,
      "status": "running", "notification_uuid": uuidsentinel.fake_notification1,
+     "failover_segment_uuid": uuidsentinel.fake_segment, "message": None,
      "created_at": NOW, "updated_at": None, "deleted_at": None, "deleted": 0},
 ]
 
@@ -104,7 +110,7 @@ NOTIFICATION_LIST = _make_notifications_list(NOTIFICATION_LIST)
 
 
 @ddt.ddt
-class NotificationTestCase(test.TestCase):
+class NotificationTestCase(base.TestCase):
     """Test Case for notifications api."""
 
     bad_request = exception.ValidationError
@@ -229,7 +235,7 @@ class NotificationTestCase(test.TestCase):
         fake_req.method = 'POST'
         fake_req.body = jsonutils.dump_as_bytes(body)
         resp = fake_req.get_response(self.app)
-        self.assertEqual(http.ACCEPTED, resp.status_code)
+        self.assertEqual(HTTPStatus.ACCEPTED, resp.status_code)
 
     @mock.patch.object(ha_api.NotificationAPI, 'create_notification')
     def test_create_host_not_found(self, mock_create):
@@ -424,10 +430,10 @@ class NotificationTestCase(test.TestCase):
         fake_req.headers['Content-Type'] = 'application/json'
         fake_req.method = method
         resp = fake_req.get_response(self.app)
-        self.assertEqual(http.METHOD_NOT_ALLOWED, resp.status_code)
+        self.assertEqual(HTTPStatus.METHOD_NOT_ALLOWED, resp.status_code)
 
 
-class NotificationCasePolicyNotAuthorized(test.NoDBTestCase):
+class NotificationCasePolicyNotAuthorized(base.NoDBTestCase):
     """Test Case for notifications non admin."""
 
     @mock.patch.object(engine_rpcapi, 'EngineAPI')
