@@ -13,7 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from http import client as http
+from http import HTTPStatus
 import inspect
 from unittest import mock
 
@@ -27,11 +27,11 @@ from masakari.api.openstack import extensions
 from masakari.api.openstack import wsgi
 from masakari.api import versioned_method
 from masakari import exception
-from masakari import test
 from masakari.tests.unit.api.openstack import fakes
+from masakari.tests.unit import base
 
 
-class MicroversionedTest(testscenarios.WithScenarios, test.NoDBTestCase):
+class MicroversionedTest(testscenarios.WithScenarios, base.NoDBTestCase):
 
     header_name = 'OpenStack-API-Version'
 
@@ -144,7 +144,7 @@ class RequestTest(MicroversionedTest):
                           request.set_api_version_request)
 
 
-class ActionDispatcherTest(test.NoDBTestCase):
+class ActionDispatcherTest(base.NoDBTestCase):
     def test_dispatch(self):
         serializer = wsgi.ActionDispatcher()
         serializer.create = lambda x: 'pants'
@@ -163,7 +163,7 @@ class ActionDispatcherTest(test.NoDBTestCase):
         self.assertEqual(serializer.dispatch({}, action='update'), 'trousers')
 
 
-class JSONDictSerializerTest(test.NoDBTestCase):
+class JSONDictSerializerTest(base.NoDBTestCase):
     def test_json(self):
         input_dict = dict(segments=dict(a=(2, 3)))
         expected_json = '{"segments":{"a":[2,3]}}'
@@ -173,7 +173,7 @@ class JSONDictSerializerTest(test.NoDBTestCase):
         self.assertEqual(result, expected_json)
 
 
-class JSONDeserializerTest(test.NoDBTestCase):
+class JSONDeserializerTest(base.NoDBTestCase):
     def test_json(self):
         data = """{"a": {
                 "a1": "1",
@@ -238,23 +238,24 @@ class ResourceTest(MicroversionedTest):
         req = webob.Request.blank('/tests')
         response = req.get_response(app)
         self.assertEqual(b'success', response.body)
-        self.assertEqual(response.status_int, http.OK)
+        self.assertEqual(response.status_int, HTTPStatus.OK)
         req.body = b'{"body": {"key": "value"}}'
         response = req.get_response(app)
         self.assertEqual(b'success', response.body)
-        self.assertEqual(response.status_int, http.OK)
+        self.assertEqual(response.status_int, HTTPStatus.OK)
         req.content_type = 'application/json'
         response = req.get_response(app)
         self.assertEqual(b'success', response.body)
-        self.assertEqual(response.status_int, http.OK)
+        self.assertEqual(response.status_int, HTTPStatus.OK)
 
     def test_resource_call_with_method_post(self):
         class Controller(object):
-            @extensions.expected_errors(http.BAD_REQUEST)
+            @extensions.expected_errors(HTTPStatus.BAD_REQUEST)
             def create(self, req, body):
                 if expected_body != body:
-                    msg = "The request body invalid"
-                    raise webob.exc.HTTPBadRequest(explanation=msg)
+                    raise exception.ConvertedException(
+                        code=HTTPStatus.BAD_REQUEST,
+                        explanation="The request body invalid")
                 return "success"
         # verify the method: POST
         app = fakes.TestRouter(Controller())
@@ -266,20 +267,21 @@ class ResourceTest(MicroversionedTest):
             }
         }
         response = req.get_response(app)
-        self.assertEqual(response.status_int, http.OK)
+        self.assertEqual(response.status_int, HTTPStatus.OK)
         self.assertEqual(b'success', response.body)
         # verify without body
         expected_body = None
         req.body = None
         response = req.get_response(app)
-        self.assertEqual(response.status_int, http.OK)
+        self.assertEqual(response.status_int, HTTPStatus.OK)
         self.assertEqual(b'success', response.body)
         # the body is validated in the controller
         expected_body = {'body': None}
         response = req.get_response(app)
         expected_unsupported_type_body = {'badRequest':
-            {'message': 'The request body invalid', 'code': http.BAD_REQUEST}}
-        self.assertEqual(response.status_int, http.BAD_REQUEST)
+            {'message': 'The request body invalid',
+             'code': HTTPStatus.BAD_REQUEST}}
+        self.assertEqual(response.status_int, HTTPStatus.BAD_REQUEST)
         self.assertEqual(expected_unsupported_type_body,
                          jsonutils.loads(response.body))
 
@@ -301,11 +303,11 @@ class ResourceTest(MicroversionedTest):
         }
         response = req.get_response(app)
         self.assertEqual(b'success', response.body)
-        self.assertEqual(response.status_int, http.OK)
+        self.assertEqual(response.status_int, HTTPStatus.OK)
         req.body = None
         expected_body = None
         response = req.get_response(app)
-        self.assertEqual(response.status_int, http.OK)
+        self.assertEqual(response.status_int, HTTPStatus.OK)
         # verify no content_type is contained in the request
         req = webob.Request.blank('/tests/test_id', method="PUT",
                                   content_type='application/xml')
@@ -314,8 +316,9 @@ class ResourceTest(MicroversionedTest):
         response = req.get_response(app)
         expected_unsupported_type_body = {'badMediaType':
             {'message': 'Unsupported Content-Type',
-             'code': http.UNSUPPORTED_MEDIA_TYPE}}
-        self.assertEqual(response.status_int, http.UNSUPPORTED_MEDIA_TYPE)
+             'code': HTTPStatus.UNSUPPORTED_MEDIA_TYPE}}
+        self.assertEqual(response.status_int,
+                         HTTPStatus.UNSUPPORTED_MEDIA_TYPE)
         self.assertEqual(expected_unsupported_type_body,
                          jsonutils.loads(response.body))
 
@@ -328,12 +331,12 @@ class ResourceTest(MicroversionedTest):
         app = fakes.TestRouter(Controller())
         req = webob.Request.blank('/tests/test_id', method="DELETE")
         response = req.get_response(app)
-        self.assertEqual(response.status_int, http.OK)
+        self.assertEqual(response.status_int, HTTPStatus.OK)
         self.assertEqual(b'success', response.body)
         # ignore the body
         req.body = b'{"body": {"key": "value"}}'
         response = req.get_response(app)
-        self.assertEqual(response.status_int, http.OK)
+        self.assertEqual(response.status_int, HTTPStatus.OK)
         self.assertEqual(b'success', response.body)
 
     def test_resource_not_authorized(self):
@@ -344,7 +347,7 @@ class ResourceTest(MicroversionedTest):
         req = webob.Request.blank('/tests')
         app = fakes.TestRouter(Controller())
         response = req.get_response(app)
-        self.assertEqual(response.status_int, http.FORBIDDEN)
+        self.assertEqual(response.status_int, HTTPStatus.FORBIDDEN)
 
     def test_dispatch(self):
         class Controller(object):
@@ -510,7 +513,7 @@ class ResourceTest(MicroversionedTest):
         response = req.get_response(app)
         self.assertIn('masakari.context', req.environ)
         self.assertEqual(b'{"foo": "bar"}', response.body)
-        self.assertEqual(response.status_int, http.OK)
+        self.assertEqual(response.status_int, HTTPStatus.OK)
 
     def test_str_response_body(self):
 
@@ -524,7 +527,7 @@ class ResourceTest(MicroversionedTest):
         expected_header = self.get_req_id_header_name(req)
         self.assertFalse(hasattr(response.headers, expected_header))
         self.assertEqual(b'foo', response.body)
-        self.assertEqual(response.status_int, http.OK)
+        self.assertEqual(response.status_int, HTTPStatus.OK)
 
     def test_get_no_response_body(self):
 
@@ -537,7 +540,7 @@ class ResourceTest(MicroversionedTest):
         response = req.get_response(app)
         self.assertIn('masakari.context', req.environ)
         self.assertEqual(b'', response.body)
-        self.assertEqual(response.status_int, http.OK)
+        self.assertEqual(response.status_int, HTTPStatus.OK)
 
     def test_deserialize_default(self):
         class Controller(object):
@@ -869,10 +872,10 @@ class ResourceTest(MicroversionedTest):
                 foo()  # generate a TypeError
             self.fail("Should have raised a Fault (HTTP 400)")
         except wsgi.Fault as fault:
-            self.assertEqual(http.BAD_REQUEST, fault.status_int)
+            self.assertEqual(HTTPStatus.BAD_REQUEST, fault.status_int)
 
     def test_resource_headers_py2_are_utf8(self):
-        resp = webob.Response(status_int=http.ACCEPTED)
+        resp = webob.Response(status_int=HTTPStatus.ACCEPTED)
         resp.headers['x-header1'] = 1
         resp.headers['x-header2'] = 'header2'
         resp.headers['x-header3'] = 'header3'
@@ -902,7 +905,7 @@ class ResourceTest(MicroversionedTest):
         app = fakes.TestRouter(Controller())
         response = req.get_response(app)
         self.assertEqual(response.body, expected_body)
-        self.assertEqual(response.status_int, http.OK)
+        self.assertEqual(response.status_int, HTTPStatus.OK)
 
     def test_resource_invalid_utf8(self):
         class Controller(object):
@@ -917,24 +920,24 @@ class ResourceTest(MicroversionedTest):
         self.assertRaises(UnicodeDecodeError, req.get_response, app)
 
 
-class ResponseObjectTest(test.NoDBTestCase):
+class ResponseObjectTest(base.NoDBTestCase):
     def test_default_code(self):
         robj = wsgi.ResponseObject({})
-        self.assertEqual(robj.code, http.OK)
+        self.assertEqual(robj.code, HTTPStatus.OK)
 
     def test_modified_code(self):
         robj = wsgi.ResponseObject({})
-        robj._default_code = http.ACCEPTED
-        self.assertEqual(robj.code, http.ACCEPTED)
+        robj._default_code = HTTPStatus.ACCEPTED
+        self.assertEqual(robj.code, HTTPStatus.ACCEPTED)
 
     def test_override_default_code(self):
-        robj = wsgi.ResponseObject({}, code=http.NOT_FOUND)
-        self.assertEqual(robj.code, http.NOT_FOUND)
+        robj = wsgi.ResponseObject({}, code=HTTPStatus.NOT_FOUND)
+        self.assertEqual(robj.code, HTTPStatus.NOT_FOUND)
 
     def test_override_modified_code(self):
-        robj = wsgi.ResponseObject({}, code=http.NOT_FOUND)
-        robj._default_code = http.ACCEPTED
-        self.assertEqual(robj.code, http.NOT_FOUND)
+        robj = wsgi.ResponseObject({}, code=HTTPStatus.NOT_FOUND)
+        robj._default_code = HTTPStatus.ACCEPTED
+        self.assertEqual(robj.code, HTTPStatus.NOT_FOUND)
 
     def test_set_header(self):
         robj = wsgi.ResponseObject({})
@@ -960,7 +963,7 @@ class ResponseObjectTest(test.NoDBTestCase):
         self.assertEqual(robj['hEADER'], 'foo')
 
 
-class ValidBodyTest(test.NoDBTestCase):
+class ValidBodyTest(base.NoDBTestCase):
 
     def setUp(self):
         super(ValidBodyTest, self).setUp()
@@ -989,7 +992,7 @@ class ValidBodyTest(test.NoDBTestCase):
         self.assertFalse(self.controller.is_valid_body(body, 'foo'))
 
 
-class TestController(test.NoDBTestCase):
+class TestController(base.NoDBTestCase):
     def test_check_for_versions_intersection_negative(self):
         func_list = [
             versioned_method.VersionedMethod('foo', (
